CompressorRef

Struct CompressorRef 

pub struct CompressorRef<'a> { /* private fields */ }
A reusable block compressor that borrows its dictionary.

This is the no-alloc API. With alloc, use Compressor instead.

For one-shot compression, use compress_into instead.

Example

use lz4rip_encode::{CompressorRef, get_maximum_output_size};

let mut comp = CompressorRef::new();
let input = b"hello world, hello world, hello!";
let mut output = vec![0u8; get_maximum_output_size(input.len())];
let compressed_len = comp.compress_into(input, &mut output).unwrap();

Implementations

Source

impl CompressorRef<'static>

pub fn new() -> Self

Create a new compressor without a dictionary.

Source

impl<'a> CompressorRef<'a>

pub fn with_dict(dict: &'a [u8]) -> Self

Create a new compressor seeded with an external dictionary.

If dict is shorter than 4 bytes, it is ignored.

pub fn compress_into( &mut self, input: &[u8], output: &mut [u8], ) -> Result<usize, CompressError>

Compress input into output, returning the number of compressed bytes.

output must be at least get_maximum_output_size(input.len()) bytes.

pub fn compress(&mut self, input: &[u8]) -> Vec<u8>

Compress input into a new Vec<u8>.