LZ4 block compression.
Structs
- Compressor
- A reusable block compressor that owns its dictionary.
- Compressor
Ref - A reusable block compressor that borrows its dictionary.
- Dict
Trainer - Trains an LZ4 dictionary from sample messages using the COVER algorithm.
Enums
- Compress
Error - Errors that can happen during compression.
Functions
- compress
- Compress all bytes of
input. - compress_
into - Compress all bytes of
inputintooutput. output should be preallocated with a size ofget_maximum_output_size. - compress_
into_ with_ dict - Compress all bytes of
inputintooutputusing an external dictionary. - get_
maximum_ output_ size - Returns the maximum output size of the compressed data. Can be used to preallocate capacity on the output vector.