Crate lz4rip_encode

Crate lz4rip_encode 

LZ4 block compression.

Structs

Compressor
A reusable block compressor. Pre-allocates the hash table once and reuses it across calls.
DictTrainer
Trains an LZ4 dictionary from sample messages using the COVER algorithm.

Enums

CompressError
Errors that can happen during compression.

Functions

compress
Compress all bytes of input.
compress_into
Compress all bytes of input into output. output should be preallocated with a size of get_maximum_output_size.
get_maximum_output_size
Returns the maximum output size of the compressed data. Can be used to preallocate capacity on the output vector