LZ4 block compression.
Structs
- Compressor
- A reusable block compressor. Pre-allocates the hash table once and reuses it across calls.
- Dict
Trainer - Trains an LZ4 dictionary from sample messages using the COVER algorithm.
Enums
- Compress
Error - Errors that can happen during compression.
Functions
- compress
- Compress all bytes of
input. - compress_
into - Compress all bytes of
inputintooutput. output should be preallocated with a size ofget_maximum_output_size. - get_
maximum_ output_ size - Returns the maximum output size of the compressed data. Can be used to preallocate capacity on the output vector