pub const fn get_maximum_output_size(input_len: usize) -> usizeExpand description
Returns the maximum output size of the compressed data. Can be used to preallocate capacity on the output vector.
Returns usize::MAX if the result would overflow (e.g. on 32-bit with >3.9 GB input).